<?php
/**
* Posts Summaries options
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function neatblog_posts_summaries_options($wp_customize) {

    $wp_customize->add_section( 'neatblog_section_posts_summaries', array( 'title' => esc_html__( 'Posts Summaries Options', 'neatblog' ), 'description' => esc_html__('To display your latest posts on your homepage, please set the "Your homepage displays" option to "Your latest posts." You can find this setting in your WordPress Dashboard by navigating to "Settings" -> "Reading" -> "Your homepage displays."', 'neatblog'), 'panel' => 'neatblog_main_options_panel', 'priority' => 160 ) );

    $wp_customize->add_setting( 'neatblog_options[hide_posts_heading]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_posts_heading_control', array( 'label' => esc_html__( 'Hide HomePage Posts Heading', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_posts_heading]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[posts_heading]', array( 'default' => esc_html__( 'Recent Posts', 'neatblog' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'neatblog_posts_heading_control', array( 'label' => esc_html__( 'HomePage Posts Heading', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[posts_heading]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'posts_per_page', array( 'default' => get_option('posts_per_page'), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'neatblog_posts_per_page_control', array( 'label' => esc_html__( 'Number of Posts per Page', 'neatblog' ), 'description' => esc_html__('Set the maximum number of posts displayed on each blog page.', 'neatblog'), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'posts_per_page', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[hide_thumbnail_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_thumbnail_home_control', array( 'label' => esc_html__( 'Hide Featured Images from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_thumbnail_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[thumbnail_link_home]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_yes_no' ) );

    $wp_customize->add_control( 'neatblog_thumbnail_link_home_control', array( 'label' => esc_html__( 'Featured Images Links', 'neatblog' ), 'description' => esc_html__('Do you want featured images in posts summaries to be linked to their posts?', 'neatblog'), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[thumbnail_link_home]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'neatblog'), 'no' => esc_html__('No', 'neatblog') ) ) );

    $wp_customize->add_setting( 'neatblog_options[hide_post_title_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_post_title_home_control', array( 'label' => esc_html__( 'Hide Post Headers from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_post_title_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[post_title_link_home]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_yes_no' ) );

    $wp_customize->add_control( 'neatblog_post_title_link_home_control', array( 'label' => esc_html__( 'Posts Titles Links', 'neatblog' ), 'description' => esc_html__('Do you want post titles in the posts summaries to be linked to their posts?', 'neatblog'), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[post_title_link_home]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'neatblog'), 'no' => esc_html__('No', 'neatblog') ) ) );

    $wp_customize->add_setting( 'neatblog_options[hide_post_author_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_post_author_home_control', array( 'label' => esc_html__( 'Hide Post Author Names from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_post_author_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_posted_date_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_posted_date_home_control', array( 'label' => esc_html__( 'Hide Posted Dates from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_posted_date_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_comments_link_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_comments_link_home_control', array( 'label' => esc_html__( 'Hide Comment Links from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_comments_link_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[post_snippet_type]', array( 'default' => 'postexcerpt', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_post_snippet_type' ) );

    $wp_customize->add_control( 'neatblog_post_snippet_type_control', array( 'label' => esc_html__( 'Snippet Type for Posts Summaries', 'neatblog' ), 'description' => esc_html__('Select "Post Content", "Post Excerpt" or "Full" snippet type for posts summaries.', 'neatblog'), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[post_snippet_type]', 'type' => 'select', 'choices' => array( 'postcontent' => esc_html__('Post Content', 'neatblog'), 'postexcerpt' => esc_html__('Post Excerpt', 'neatblog'), 'full' => esc_html__('Full', 'neatblog') ) ) );

    $wp_customize->add_setting( 'neatblog_options[hide_post_snippet]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_post_snippet_control', array( 'label' => esc_html__( 'Hide Post Content from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_post_snippet]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[read_more_length]', array( 'default' => 40, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_read_more_length' ) );

    $wp_customize->add_control( 'neatblog_read_more_length_control', array( 'label' => esc_html__( 'Post Snippet Length', 'neatblog' ), 'description' => esc_html__('Enter the number of words need to display in the post summary. Default is 40 words. This option only works if you select "Post Content" or "Post Excerpt" value for "Snippet Type for Posts Summaries" option.', 'neatblog'), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[read_more_length]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[hide_post_categories_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_post_categories_home_control', array( 'label' => esc_html__( 'Hide Post Categories from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_post_categories_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_post_tags_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_post_tags_home_control', array( 'label' => esc_html__( 'Hide Post Tags from Posts Summaries', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[hide_post_tags_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[thumbnail_alignment_post_summaries]', array( 'default' => 'neatblog-thumbnail-alignwide', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_thumbnail_alignment' ) );

    $wp_customize->add_control( 'neatblog_thumbnail_alignment_post_summaries_control', array( 'label' => esc_html__( 'Featured Images Alignment of Posts Summaries', 'neatblog' ), 'description' => esc_html__('Select the alignment of featured images in posts summaries.', 'neatblog'), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[thumbnail_alignment_post_summaries]', 'type' => 'select', 'choices' => array( 'neatblog-thumbnail-aligncenter' => esc_html__('Center', 'neatblog'), 'neatblog-thumbnail-alignwide' => esc_html__('Wide', 'neatblog'), 'neatblog-thumbnail-alignfull' => esc_html__('Full', 'neatblog') ) ) );

    $wp_customize->add_setting( 'neatblog_options[featured_summaries_media_above_post_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_featured_summaries_media_above_post_title_control', array( 'label' => esc_html__( 'Move Featured Images to the Top of Post Summaries Titles', 'neatblog' ), 'section' => 'neatblog_section_posts_summaries', 'settings' => 'neatblog_options[featured_summaries_media_above_post_title]', 'type' => 'checkbox', ) );

}