<?php
/**
* Page options
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function neatblog_page_options($wp_customize) {

    $wp_customize->add_section( 'neatblog_section_page', array( 'title' => esc_html__( 'Page Options', 'neatblog' ), 'panel' => 'neatblog_main_options_panel', 'priority' => 190 ) );

    $wp_customize->add_setting( 'neatblog_options[thumbnail_alignment_page]', array( 'default' => 'neatblog-thumbnail-alignwide', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_thumbnail_alignment' ) );

    $wp_customize->add_control( 'neatblog_thumbnail_alignment_page_control', array( 'label' => esc_html__( 'Featured Image Alignment', 'neatblog' ), 'description' => esc_html__('Select the alignment of featured image in single page.', 'neatblog'), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[thumbnail_alignment_page]', 'type' => 'select', 'choices' => array( 'neatblog-thumbnail-aligncenter' => esc_html__('Center', 'neatblog'), 'neatblog-thumbnail-alignwide' => esc_html__('Wide', 'neatblog'), 'neatblog-thumbnail-alignfull' => esc_html__('Full', 'neatblog') ) ) );

    $wp_customize->add_setting( 'neatblog_options[thumbnail_link_page]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_yes_no' ) );

    $wp_customize->add_control( 'neatblog_thumbnail_link_page_control', array( 'label' => esc_html__( 'Featured Image Link', 'neatblog' ), 'description' => esc_html__('Do you want the featured image in a page to be linked to its page?', 'neatblog'), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[thumbnail_link_page]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'neatblog'), 'no' => esc_html__('No', 'neatblog') ) ) );

    $wp_customize->add_setting( 'neatblog_options[hide_page_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_page_thumbnail_control', array( 'label' => esc_html__( 'Hide Featured Image from Single Page', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[hide_page_thumbnail]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[featured_media_above_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_featured_media_above_page_title_control', array( 'label' => esc_html__( 'Move Featured Image to the Top of Page Title', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[featured_media_above_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_page_title_control', array( 'label' => esc_html__( 'Hide Page Header from Single Page', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[hide_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[remove_page_title_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_remove_page_title_link_control', array( 'label' => esc_html__( 'Remove Link from Single Page Title', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[remove_page_title_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_page_date]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_page_date_control', array( 'label' => esc_html__( 'Hide Posted Date from Single Page', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[hide_page_date]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_page_author]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_page_author_control', array( 'label' => esc_html__( 'Hide Page Author from Single Page', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[hide_page_author]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_page_comments]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_page_comments_control', array( 'label' => esc_html__( 'Hide Comment Link from Single Page', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[hide_page_comments]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[show_page_edit]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_show_page_edit_control', array( 'label' => esc_html__( 'Show Edit Link on Single Page', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[show_page_edit]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_static_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_static_page_title_control', array( 'label' => esc_html__( 'Hide Page Header from Static Homepage', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[hide_static_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_static_page_meta]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_static_page_meta_control', array( 'label' => esc_html__( 'Hide Page Meta Data (Page Date, Page Author, Comment Link) from Static Homepage', 'neatblog' ), 'section' => 'neatblog_section_page', 'settings' => 'neatblog_options[hide_static_page_meta]', 'type' => 'checkbox', ) );

}