<?php
/**
* Social profiles options
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function neatblog_social_profiles($wp_customize) {

    $wp_customize->add_section( 'neatblog_section_social', array( 'title' => esc_html__( 'Social Links Options', 'neatblog' ), 'panel' => 'neatblog_main_options_panel', 'priority' => 240, ));

    $wp_customize->add_setting( 'neatblog_options[hide_header_social_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_header_social_buttons_control', array( 'label' => esc_html__( 'Hide Social Area', 'neatblog' ), 'description' => esc_html__('If you checked this option, all buttons will disappear. There is no any effect from these options: "Hide Search Button", "Show Login/Logout Button", "Show Random Post Button".', 'neatblog'), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[hide_header_social_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[hide_search_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_hide_search_button_control', array( 'label' => esc_html__( 'Hide Search Button', 'neatblog' ), 'description' => esc_html__('This option has no effect if you have checked the option: "Hide Social Area".', 'neatblog'), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[hide_search_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[show_login_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_checkbox', ) );

    $wp_customize->add_control( 'neatblog_show_login_button_control', array( 'label' => esc_html__( 'Show Login/Logout Button', 'neatblog' ), 'description' => esc_html__('This option has no effect if you have checked the option: "Hide Social Area".', 'neatblog'), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[show_login_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'neatblog_options[twitterlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_twitterlink_control', array( 'label' => esc_html__( 'X URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[twitterlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[facebooklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_facebooklink_control', array( 'label' => esc_html__( 'Facebook URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[facebooklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[threadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_threadslink_control', array( 'label' => esc_html__( 'Threads URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[threadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[pinterestlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_pinterestlink_control', array( 'label' => esc_html__( 'Pinterest URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[pinterestlink]', 'type' => 'text' ) );
    
    $wp_customize->add_setting( 'neatblog_options[linkedinlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_linkedinlink_control', array( 'label' => esc_html__( 'Linkedin Link', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[linkedinlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[instagramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_instagramlink_control', array( 'label' => esc_html__( 'Instagram Link', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[instagramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[vklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_vklink_control', array( 'label' => esc_html__( 'VK Link', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[vklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[flickrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_flickrlink_control', array( 'label' => esc_html__( 'Flickr Link', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[flickrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[youtubelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_youtubelink_control', array( 'label' => esc_html__( 'Youtube URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[youtubelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[vimeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_vimeolink_control', array( 'label' => esc_html__( 'Vimeo URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[vimeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[soundcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_soundcloudlink_control', array( 'label' => esc_html__( 'Soundcloud URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[soundcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[messengerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_messengerlink_control', array( 'label' => esc_html__( 'Messenger URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[messengerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[whatsapplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_whatsapplink_control', array( 'label' => esc_html__( 'WhatsApp URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[whatsapplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[tiktoklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_tiktoklink_control', array( 'label' => esc_html__( 'TikTok URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[tiktoklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[lastfmlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_lastfmlink_control', array( 'label' => esc_html__( 'Lastfm URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[lastfmlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[mediumlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_mediumlink_control', array( 'label' => esc_html__( 'Medium URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[mediumlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[githublink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_githublink_control', array( 'label' => esc_html__( 'Github URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[githublink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[bitbucketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_bitbucketlink_control', array( 'label' => esc_html__( 'Bitbucket URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[bitbucketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[tumblrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_tumblrlink_control', array( 'label' => esc_html__( 'Tumblr URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[tumblrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[digglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_digglink_control', array( 'label' => esc_html__( 'Digg URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[digglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[deliciouslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_deliciouslink_control', array( 'label' => esc_html__( 'Delicious URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[deliciouslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[stumblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_stumblelink_control', array( 'label' => esc_html__( 'Stumbleupon URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[stumblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[mixlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_mixlink_control', array( 'label' => esc_html__( 'Mix URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[mixlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[redditlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_redditlink_control', array( 'label' => esc_html__( 'Reddit URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[redditlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[dribbblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_dribbblelink_control', array( 'label' => esc_html__( 'Dribbble URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[dribbblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[flipboardlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_flipboardlink_control', array( 'label' => esc_html__( 'Flipboard URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[flipboardlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[bloggerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_bloggerlink_control', array( 'label' => esc_html__( 'Blogger URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[bloggerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[etsylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_etsylink_control', array( 'label' => esc_html__( 'Etsy URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[etsylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[behancelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_behancelink_control', array( 'label' => esc_html__( 'Behance URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[behancelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[amazonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_amazonlink_control', array( 'label' => esc_html__( 'Amazon URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[amazonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[meetuplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_meetuplink_control', array( 'label' => esc_html__( 'Meetup URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[meetuplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[mixcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_mixcloudlink_control', array( 'label' => esc_html__( 'Mixcloud URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[mixcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[slacklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_slacklink_control', array( 'label' => esc_html__( 'Slack URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[slacklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[snapchatlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_snapchatlink_control', array( 'label' => esc_html__( 'Snapchat URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[snapchatlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[spotifylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_spotifylink_control', array( 'label' => esc_html__( 'Spotify URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[spotifylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[yelplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_yelplink_control', array( 'label' => esc_html__( 'Yelp URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[yelplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[wordpresslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_wordpresslink_control', array( 'label' => esc_html__( 'WordPress URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[wordpresslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[twitchlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_twitchlink_control', array( 'label' => esc_html__( 'Twitch URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[twitchlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[telegramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_telegramlink_control', array( 'label' => esc_html__( 'Telegram URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[telegramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[bandcamplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_bandcamplink_control', array( 'label' => esc_html__( 'Bandcamp URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[bandcamplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[quoralink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_quoralink_control', array( 'label' => esc_html__( 'Quora URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[quoralink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[foursquarelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_foursquarelink_control', array( 'label' => esc_html__( 'Foursquare URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[foursquarelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[deviantartlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_deviantartlink_control', array( 'label' => esc_html__( 'DeviantArt URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[deviantartlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[imdblink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_imdblink_control', array( 'label' => esc_html__( 'IMDB URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[imdblink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[codepenlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_codepenlink_control', array( 'label' => esc_html__( 'Codepen URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[codepenlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[jsfiddlelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_jsfiddlelink_control', array( 'label' => esc_html__( 'JSFiddle URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[jsfiddlelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[stackoverflowlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_stackoverflowlink_control', array( 'label' => esc_html__( 'Stack Overflow URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[stackoverflowlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[stackexchangelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_stackexchangelink_control', array( 'label' => esc_html__( 'Stack Exchange URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[stackexchangelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[bsalink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_bsalink_control', array( 'label' => esc_html__( 'BuySellAds URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[bsalink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[web500pxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_web500pxlink_control', array( 'label' => esc_html__( '500px URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[web500pxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[ellolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_ellolink_control', array( 'label' => esc_html__( 'Ello URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[ellolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[discordlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_discordlink_control', array( 'label' => esc_html__( 'Discord URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[discordlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[goodreadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_goodreadslink_control', array( 'label' => esc_html__( 'Goodreads URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[goodreadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[odnoklassnikilink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_odnoklassnikilink_control', array( 'label' => esc_html__( 'Odnoklassniki URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[odnoklassnikilink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[houzzlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_houzzlink_control', array( 'label' => esc_html__( 'Houzz URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[houzzlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[pocketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_pocketlink_control', array( 'label' => esc_html__( 'Pocket URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[pocketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[xinglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_xinglink_control', array( 'label' => esc_html__( 'XING URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[xinglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[mastodonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_mastodonlink_control', array( 'label' => esc_html__( 'Mastodon URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[mastodonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[googleplaylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_googleplaylink_control', array( 'label' => esc_html__( 'Google Play URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[googleplaylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[slidesharelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_slidesharelink_control', array( 'label' => esc_html__( 'SlideShare URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[slidesharelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[dropboxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_dropboxlink_control', array( 'label' => esc_html__( 'Dropbox URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[dropboxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[paypallink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_paypallink_control', array( 'label' => esc_html__( 'PayPal URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[paypallink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[viadeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_viadeolink_control', array( 'label' => esc_html__( 'Viadeo URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[viadeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[wikipedialink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_wikipedialink_control', array( 'label' => esc_html__( 'Wikipedia URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[wikipedialink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[skypeusername]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'neatblog_skypeusername_control', array( 'label' => esc_html__( 'Skype Username', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[skypeusername]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[emailaddress]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'neatblog_sanitize_email' ) );

    $wp_customize->add_control( 'neatblog_emailaddress_control', array( 'label' => esc_html__( 'Email Address', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[emailaddress]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'neatblog_options[rsslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'neatblog_rsslink_control', array( 'label' => esc_html__( 'RSS Feed URL', 'neatblog' ), 'section' => 'neatblog_section_social', 'settings' => 'neatblog_options[rsslink]', 'type' => 'text' ) );

}