<?php
/**
* Upgrade to pro options
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license licennse URI, for example : http://www.gnu.org/licenses/gpl-2.0.html
* @author ThemesDNA <themesdna@gmail.com>
*/

function neatblog_upgrade_to_pro($wp_customize) {

    $wp_customize->add_section( 'neatblog_section_upgrade', array( 'title' => esc_html__( 'Upgrade to Pro Version', 'neatblog' ), 'priority' => 400 ) );
    
    $wp_customize->add_setting( 'neatblog_options[upgrade_text]', array( 'default' => '', 'sanitize_callback' => '__return_false', ) );
    
    $wp_customize->add_control( new NeatBlog_Customize_Static_Text_Control( $wp_customize, 'neatblog_upgrade_text_control', array(
        'label'       => esc_html__( 'NeatBlog Pro', 'neatblog' ),
        'section'     => 'neatblog_section_upgrade',
        'settings' => 'neatblog_options[upgrade_text]',
        'description' => esc_html__( 'Do you enjoy NeatBlog? Upgrade to NeatBlog Pro now and get:', 'neatblog' ).
            '<ul class="neatblog-customizer-pro-features">' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Color Options', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Font Options', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Switch between Boxed or Full Layout Type', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Width Change Options for Header/Main Content/Footer', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( '3 Header Layouts with Width options - (Logo + Primary Menu + Social Buttons) / (Logo + Header Banner) / (Full Width Header)', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Footer with Layout Options (1/2/3/4/5/6 columns)', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to Change Website Width/Layout Type/Header Style/Footer Style of any Post/Page', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Capability to Add Different Header Images for Each Post/Page with Unique Link, Title and Description', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'List Featured Posts Widget (Recent/Categories/Tags/PostIDs based) - with capability to display posts according to Likes/Views/Comments/Dates/... and there are many options', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Tabbed Featured Posts Widget (Recent/Categories/Tags/PostIDs based) - with capability to display posts according to Likes/Views/Comments/Dates/... and there are many options.', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'About and Social Widget - 60+ Social Buttons', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'News Ticker (Recent/Categories/Tags/PostIDs based) - It can display posts according to Likes/Views/Comments/Dates/... and there are many options.', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Settings Panel to Control Options in Each Post', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Settings Panel to Control Options in Each Page', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Posts Views Counter', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Posts Likes System', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Infinite Scroll and Load More Button', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'More Post Share Buttons - 25+ Social Networks are Supported', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Related Posts (Categories/Tags/Author/PostIDs based) with Many Options - For both single posts and post summaries', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Thumbnail Sizes Options for Posts/Pages', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Custom Page Templates', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Author Bio Box with Social Buttons - 60+ Social Buttons', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to Enable/Disable Mobile View from Primary and Secondary Menus', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Post Navigation with Thumbnails', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to add Ads under Post Title and under Post Content', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to Disable Google Fonts - for faster loading', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'More Widget Areas', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Contact Form', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'WooCommerce Compatible', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Yoast SEO Breadcrumbs Support', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Full RTL Language Support', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Search Engine Optimized', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Random Posts Button', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'Many Useful Customizer Theme options', 'neatblog' ) . '</li>' .
                '<li><i class="fa-solid fa-check" aria-hidden="true"></i> ' . esc_html__( 'More Features...', 'neatblog' ) . '</li>' .
            '</ul>'.
            '<strong><a href="'.NEATBLOG_PROURL.'" class="button button-primary" target="_blank"><i class="fa-solid fa-cart-shopping" aria-hidden="true"></i> ' . esc_html__( 'Upgrade To NeatBlog PRO', 'neatblog' ) . '</a></strong>'
    ) ) );

}