<?php
/**
* Enqueue scripts and styles
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function neatblog_scripts() {
    wp_enqueue_style('neatblog-maincss', get_stylesheet_uri(), array(), null);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
    wp_enqueue_style('neatblog-webfont', '//fonts.googleapis.com/css?family=Poppins:400,400i,500,500i,700,700i&amp;display=swap', array(), null);

    $neatblog_fitvids_active = false;
    if ( neatblog_is_fitvids_active() ) {
        $neatblog_fitvids_active = true;
    }
    if ( $neatblog_fitvids_active ) {
        wp_enqueue_script('fitvids', get_template_directory_uri() .'/assets/js/jquery.fitvids.min.js', array( 'jquery' ), null, true);
    }

    $neatblog_backtotop_active = false;
    if ( neatblog_is_backtotop_active() ) {
        $neatblog_backtotop_active = true;
    }

    $neatblog_primary_menu_active = false;
    if ( neatblog_is_primary_menu_active() ) {
        $neatblog_primary_menu_active = true;
    }
    $neatblog_secondary_menu_active = false;
    if ( neatblog_is_secondary_menu_active() ) {
        $neatblog_secondary_menu_active = true;
    }

    $neatblog_sticky_header_active = false;
    $neatblog_sticky_header_mobile_active = false;
    if ( neatblog_is_sticky_header_active() ) {
        $neatblog_sticky_header_active = true;
    }
    if ( neatblog_is_sticky_mobile_header_active() ) {
        $neatblog_sticky_header_mobile_active = true;
    }

    $neatblog_posts_navigation_active = true;
    if ( neatblog_get_option('hide_posts_navigation') ) {
        $neatblog_posts_navigation_active = false;
    }

    wp_enqueue_script('neatblog-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), null, true );
    wp_enqueue_script('neatblog-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), null, true );
    wp_enqueue_script('neatblog-customjs', get_template_directory_uri() .'/assets/js/custom.js', array( 'jquery', 'imagesloaded' ), null, true);

    wp_localize_script( 'neatblog-customjs', 'neatblog_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $neatblog_primary_menu_active,
            'secondary_menu_active' => $neatblog_secondary_menu_active,
            'sticky_header_active' => $neatblog_sticky_header_active,
            'sticky_header_mobile_active' => $neatblog_sticky_header_mobile_active,
            'fitvids_active' => $neatblog_fitvids_active,
            'backtotop_active' => $neatblog_backtotop_active,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('neatblog-html5shiv-js', get_template_directory_uri() .'/assets/js/html5shiv.js', array('jquery'), null, true);

    wp_localize_script('neatblog-html5shiv-js','neatblog_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'neatblog'),
    ));
}
add_action( 'wp_enqueue_scripts', 'neatblog_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function neatblog_ie_scripts() {
    wp_enqueue_script( 'respond', get_template_directory_uri(). '/assets/js/respond.min.js', array(), null, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'neatblog_ie_scripts' );

/**
 * Enqueue styles for the block-based editor.
 */
function neatblog_block_editor_styles() {
    wp_enqueue_style( 'neatblog-block-editor-style', get_template_directory_uri() . '/assets/css/editor-blocks.css', array(), null );
}
add_action( 'enqueue_block_editor_assets', 'neatblog_block_editor_styles' );

/**
 * Enqueue customizer styles.
 */
function neatblog_enqueue_customizer_styles() {
    wp_enqueue_style( 'neatblog-customizer-styles', get_template_directory_uri() . '/inc/admin/css/customizer-style.css', array(), null );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/assets/css/all.min.css', array(), null );
}
add_action( 'customize_controls_enqueue_scripts', 'neatblog_enqueue_customizer_styles' );