<?php
/**
* Menu Functions
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

// Get our wp_nav_menu() fallback, wp_page_menu(), to show a "Home" link as the first item
function neatblog_page_menu_args( $args ) {
    $args['show_home'] = true;
    return $args;
}
add_filter( 'wp_page_menu_args', 'neatblog_page_menu_args' );

function neatblog_primary_menu_text() {
   $menu_text = esc_html__( 'Menu', 'neatblog' );
    if ( neatblog_get_option('primary_menu_text') ) {
        $menu_text = neatblog_get_option('primary_menu_text');
    }
   return apply_filters( 'neatblog_primary_menu_text', $menu_text );
}

function neatblog_secondary_menu_text() {
   $menu_text = esc_html__( 'Menu', 'neatblog' );
    if ( neatblog_get_option('secondary_menu_text') ) {
        $menu_text = neatblog_get_option('secondary_menu_text');
    }
   return apply_filters( 'neatblog_secondary_menu_text', $menu_text );
}

function neatblog_top_fallback_menu() {
   wp_page_menu( array(
        'sort_column'  => 'menu_order, post_title',
        'menu_id'      => 'neatblog-menu-secondary-navigation',
        'menu_class'   => 'neatblog-secondary-nav-menu neatblog-menu-secondary',
        'container'    => 'ul',
        'echo'         => true,
        'link_before'  => '',
        'link_after'   => '',
        'before'       => '',
        'after'        => '',
        'item_spacing' => 'discard',
        'walker'       => '',
    ) );
}

function neatblog_fallback_menu() {
   wp_page_menu( array(
        'sort_column'  => 'menu_order, post_title',
        'menu_id'      => 'neatblog-menu-primary-navigation',
        'menu_class'   => 'neatblog-primary-nav-menu neatblog-menu-primary',
        'container'    => 'ul',
        'echo'         => true,
        'link_before'  => '',
        'link_after'   => '',
        'before'       => '',
        'after'        => '',
        'item_spacing' => 'discard',
        'walker'       => '',
    ) );
}

function neatblog_secondary_menu_area() {
if ( neatblog_is_menu_social_bar_active() ) { ?>
<div class="neatblog-container neatblog-secondary-menu-container neatblog-clearfix">
<div class="neatblog-secondary-menu-container-inside neatblog-clearfix">
<nav class="neatblog-nav-secondary" id="neatblog-secondary-navigation" itemscope="itemscope" itemtype="http://schema.org/SiteNavigationElement" role="navigation" aria-label="<?php esc_attr_e( 'Secondary Menu', 'neatblog' ); ?>">
<div class="neatblog-outer-wrapper neatblog-outer-wrapper-smenu">

<?php if ( neatblog_is_secondary_menu_active() ) { ?>
<button class="neatblog-secondary-responsive-menu-icon" aria-controls="neatblog-menu-secondary-navigation" aria-expanded="false"><?php echo esc_html( neatblog_secondary_menu_text() ); ?></button>
<?php wp_nav_menu( array( 'theme_location' => 'secondary', 'menu_id' => 'neatblog-menu-secondary-navigation', 'menu_class' => 'neatblog-secondary-nav-menu neatblog-menu-secondary neatblog-clearfix', 'fallback_cb' => 'neatblog_top_fallback_menu', 'container' => '', ) ); ?>
<?php } ?>

<?php if ( neatblog_is_social_buttons_active() ) { ?>
<?php neatblog_social_buttons(); ?>

<?php if ( !(neatblog_get_option('hide_search_button')) ) { ?>
<div id="neatblog-search-overlay-wrap" class="neatblog-search-overlay">
  <div class="neatblog-search-overlay-content">
    <?php get_search_form(); ?>
  </div>
  <button class="neatblog-search-closebtn" aria-label="<?php esc_attr_e( 'Close Search', 'neatblog' ); ?>" title="<?php esc_attr_e('Close Search','neatblog'); ?>">&#xD7;</button>
</div>
<?php } ?>
<?php } ?>

</div>
</nav>
</div>
</div>
<?php }
}