<?php
/**
* More Custom Functions
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

// Change excerpt length
function neatblog_excerpt_length($length) {
    if ( is_admin() ) {
        return $length;
    }
    $read_more_length = 40;
    if ( neatblog_get_option('read_more_length') ) {
        $read_more_length = neatblog_get_option('read_more_length');
    }
    return apply_filters( 'neatblog_excerpt_length', $read_more_length );
}
add_filter('excerpt_length', 'neatblog_excerpt_length');


function neatblog_post_snippet_length() {
    $snippet_length = 40;
    if ( neatblog_get_option('read_more_length') ) {
        $snippet_length = neatblog_get_option('read_more_length');
    }
    return apply_filters( 'neatblog_post_snippet_length', $snippet_length );
}


// Change excerpt more word
function neatblog_excerpt_more($more) {
    if ( is_admin() ) {
        return $more;
    }
    return '...';
}
add_filter('excerpt_more', 'neatblog_excerpt_more');


if ( ! function_exists( 'wp_body_open' ) ) :
    /**
     * Fire the wp_body_open action.
     *
     * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
     */
    function wp_body_open() { // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedFunctionFound
        /**
         * Triggered after the opening <body> tag.
         */
        do_action( 'wp_body_open' ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
    }
endif;


function neatblog_add_menu_search_button( $items, $args ) {

    // Only used for the main menu
    if ( 'primary' != $args->theme_location ) {
        return $items;
    }

    $search_button = '';
    if ( neatblog_get_option('show_header_search_button') ) {
        $search_button = '<li class="neatblog-header-icon-search-item"><a href="' . esc_url( '#' ) . '" aria-label="'.esc_attr__('Search Button','neatblog').'" class="neatblog-header-icon-search"><i class="fa-solid fa-magnifying-glass" aria-hidden="true" title="'.esc_attr__('Search','neatblog').'"></i></a></li>';
    }

    $items = $items . $search_button;
    return $items;

}
add_filter( 'wp_nav_menu_items', 'neatblog_add_menu_search_button', 10, 2 );