<?php
/**
* Post meta functions
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function neatblog_post_cat_links_text() {
    if ( neatblog_is_option_set('cat_links_text') ) {
        $cat_links_text = neatblog_get_option('cat_links_text');
    } else {
        $cat_links_text = esc_html__( 'Posted in', 'neatblog' );
    }
    return apply_filters( 'neatblog_post_cat_links_text', $cat_links_text );
}

function neatblog_post_tag_links_text() {
    if ( neatblog_is_option_set('tag_links_text') ) {
        $tag_links_text = neatblog_get_option('tag_links_text');
    } else {
        $tag_links_text = esc_html__( 'Tagged', 'neatblog' );
    }
    return apply_filters( 'neatblog_post_tag_links_text', $tag_links_text );
}

if ( ! function_exists( 'neatblog_post_tags' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function neatblog_post_tags() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'neatblog' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */
            printf( '<span class="neatblog-tags-links"><i class="fa-solid fa-tags" aria-hidden="true"></i> ' . esc_html__( 'Tagged %1$s', 'neatblog' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'neatblog_single_cats' ) ) :
function neatblog_single_cats() {
    if ( 'post' == get_post_type() ) {
        /* translators: used between list items, there is a space */
        $categories_list = get_the_category_list( esc_html__( ', ', 'neatblog' ) );
        if ( $categories_list ) {
            /* translators: 1: list of categories. */
            printf( '<span class="neatblog-entry-meta-single-cats"><i class="fa-solid fa-folder-open" aria-hidden="true"></i>&nbsp;' . __( '<span class="neatblog-sr-only">Posted in </span>%1$s', 'neatblog' ) . '</span>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        }
    }
}
endif;


if ( ! function_exists( 'neatblog_summaries_postmeta' ) ) :
function neatblog_summaries_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(neatblog_get_option('hide_post_author_home')) || !(neatblog_get_option('hide_posted_date_home')) || (!(neatblog_get_option('hide_comments_link_home')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) || (!(neatblog_get_option('hide_post_categories_home')) && has_category()) ) { ?>
    <div class="neatblog-entry-meta-single">
    <?php if ( !(neatblog_get_option('hide_post_author_home')) ) { ?><span class="neatblog-entry-meta-single-author"><i class="fa-solid fa-circle-user" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(neatblog_get_option('hide_posted_date_home')) ) { ?><span class="neatblog-entry-meta-single-date"><i class="fa-solid fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(neatblog_get_option('hide_comments_link_home')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="neatblog-entry-meta-single-comments"><i class="fa-solid fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="neatblog-sr-only"> on %s</span>', 'neatblog' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( (!(neatblog_get_option('hide_post_categories_home')) && has_category()) ) { ?><?php neatblog_single_cats(); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'neatblog_single_postmeta' ) ) :
function neatblog_single_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(neatblog_get_option('hide_post_author')) || !(neatblog_get_option('hide_posted_date')) || (!(neatblog_get_option('hide_comments_link')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) || (!(neatblog_get_option('hide_post_categories')) && has_category()) || neatblog_get_option('show_post_edit') ) { ?>
    <div class="neatblog-entry-meta-single">
    <?php if ( !(neatblog_get_option('hide_post_author')) ) { ?><span class="neatblog-entry-meta-single-author"><i class="fa-solid fa-circle-user" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(neatblog_get_option('hide_posted_date')) ) { ?><span class="neatblog-entry-meta-single-date"><i class="fa-solid fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(neatblog_get_option('hide_comments_link')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="neatblog-entry-meta-single-comments"><i class="fa-solid fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="neatblog-sr-only"> on %s</span>', 'neatblog' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    <?php if ( (!(neatblog_get_option('hide_post_categories')) && has_category()) ) { ?><?php neatblog_single_cats(); ?><?php } ?>
    <?php if ( neatblog_get_option('show_post_edit') ) { ?><?php edit_post_link( sprintf( wp_kses( /* translators: %s: Name of current post. Only visible to screen readers */ __( 'Edit<span class="neatblog-sr-only"> %s</span>', 'neatblog' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ), '<span class="edit-link">&nbsp;&nbsp;<i class="fa-solid fa-pen-to-square" aria-hidden="true"></i> ', '</span>' ); ?><?php } ?>
    </div>
    <?php } ?>
<?php }
endif;


if ( ! function_exists( 'neatblog_page_postmeta' ) ) :
function neatblog_page_postmeta() { ?>
    <?php global $post; ?>
    <?php if ( !(neatblog_get_option('hide_page_author')) || !(neatblog_get_option('hide_page_date')) || (!(neatblog_get_option('hide_page_comments')) && (! post_password_required() && ( comments_open() || get_comments_number() ))) ) { ?>
    <?php if ( !((is_front_page()) && (neatblog_get_option('hide_static_page_meta'))) ) { ?>
    <div class="neatblog-entry-meta-single">
    <?php if ( !(neatblog_get_option('hide_page_author')) ) { ?><span class="neatblog-entry-meta-single-author"><i class="fa-solid fa-circle-user" aria-hidden="true"></i>&nbsp;<span class="author vcard" itemscope="itemscope" itemtype="http://schema.org/Person" itemprop="author"><a class="url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>"><?php echo esc_html( get_the_author() ); ?></a></span></span><?php } ?>
    <?php if ( !(neatblog_get_option('hide_page_date')) ) { ?><span class="neatblog-entry-meta-single-date"><i class="fa-solid fa-clock" aria-hidden="true"></i>&nbsp;<?php echo esc_html( get_the_date() ); ?></span><?php } ?>
    <?php if ( !(neatblog_get_option('hide_page_comments')) ) { ?><?php if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) { ?>
    <span class="neatblog-entry-meta-single-comments"><i class="fa-solid fa-comments" aria-hidden="true"></i>&nbsp;<?php comments_popup_link( sprintf( wp_kses( /* translators: %s: post title */ __( 'Leave a Comment<span class="neatblog-sr-only"> on %s</span>', 'neatblog' ), array( 'span' => array( 'class' => array(), ), ) ), wp_kses_post( get_the_title() ) ) ); ?></span>
    <?php } ?><?php } ?>
    </div>
    <?php } ?>
    <?php } ?>
<?php }
endif;