<?php
/**
* Post share buttons
*
* @package NeatBlog WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

function neatblog_share_text() {
    $sharetext = esc_html__( 'Share:', 'neatblog' );
    if ( neatblog_get_option('hide_share_text') ) {return;}
    if ( neatblog_get_option('share_text') ) {
        $sharetext = neatblog_get_option('share_text');
    }
    return apply_filters( 'neatblog_share_text', $sharetext );
}

function neatblog_social_sharing_buttons() {

        global $post;

        // Get current page URL 
        $posturl = rawurlencode(get_permalink($post->ID));

        // Get current page title
        $posttitle = the_title_attribute('echo=0');
        $posttitle = !empty($posttitle) ? rawurlencode($posttitle) : '';

        // Construct sharing URL without using any script
        $x_url = 'https://x.com/intent/post?text='.$posttitle.'&amp;url='.$posturl;
        $facebook_url = 'https://www.facebook.com/sharer.php?u='.$posturl;
        $linkedin_url = 'https://www.linkedin.com/shareArticle?mini=true&amp;title='.$posttitle.'&amp;url='.$posturl;

        $postthumb = '';
        $postthumb_attributes = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full', false );
        $postthumb = isset($postthumb_attributes[0]) ? $postthumb_attributes[0] : '';

        if(!empty($postthumb)) {
            $pinterest_url = 'https://pinterest.com/pin/create/button/?url='.$posturl.'&amp;media='.$postthumb.'&amp;description='.$posttitle;
        }

        // Add sharing button at the end of page/page content
        $socialcontent = '<div class="neatblog-share-buttons neatblog-clearfix"><span class="neatblog-share-text">'.esc_html(neatblog_share_text()).' </span>';
        if ( !(neatblog_get_option('hide_share_twitter')) ) {
            $socialcontent .= '<a class="neatblog-share-buttons-twitter" href="'.esc_url($x_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on X', 'neatblog').'"><i class="fa-brands fa-twitter" aria-hidden="true"></i>'.esc_html__('X', 'neatblog').'</a>';
        }
        if ( !(neatblog_get_option('hide_share_facebook')) ) {
            $socialcontent .= '<a class="neatblog-share-buttons-facebook" href="'.esc_url($facebook_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Facebook', 'neatblog').'"><i class="fa-brands fa-facebook-f" aria-hidden="true"></i>'.esc_html__('Facebook', 'neatblog').'</a>';
        }
        if ( !(neatblog_get_option('hide_share_pinterest')) && !(empty($postthumb)) ) {
            $socialcontent .= '<a class="neatblog-share-buttons-pinterest" href="'.esc_url($pinterest_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Pinterest', 'neatblog').'"><i class="fa-brands fa-pinterest" aria-hidden="true"></i>'.esc_html__('Pinterest', 'neatblog').'</a>';
        }
        if ( !(neatblog_get_option('hide_share_linkedin')) ) {
            $socialcontent .= '<a class="neatblog-share-buttons-linkedin" href="'.esc_url($linkedin_url).'" target="_blank" rel="nofollow" title="'.esc_attr__('Share this on Linkedin', 'neatblog').'"><i class="fa-brands fa-linkedin-in" aria-hidden="true"></i>'.esc_html__('Linkedin', 'neatblog').'</a>';
        }
        $socialcontent .= '</div>';

        return apply_filters( 'neatblog_social_sharing_buttons', $socialcontent );

}